Tool priority: Read > Glob > Grep > Task > Bash
- Specialized tools over bash commands
- Parallel independent calls, sequential dependent calls
- Read files before editing
- Use Task tool for complex exploration
